@@ -49,7 +49,7 @@ class TestClusterObject(base.TestCase):
         cluster.cluster_template_id = wtypes.Unset
         self.assertEqual(wtypes.Unset, cluster.cluster_template_id)
 
-        # test backwards compatibility of bay fields with new objects
+        # test backwards compatibility of cluster fields with new objects
         cluster_dict['create_timeout'] = 15
         cluster = api_cluster.Cluster(**cluster_dict)
         self.assertEqual(15, cluster.create_timeout)
@@ -189,7 +189,8 @@ class TestListCluster(api_base.FunctionalTest):
     @mock.patch("magnum.common.context.make_context")
     @mock.patch("magnum.objects.Cluster.obj_load_attr")
     @mock.patch("magnum.objects.Cluster.cluster_template")
-    def test_get_all_with_all_projects(self, mock_context, mock_policy, mock_load, mock_template):
+    def test_get_all_with_all_projects(self, mock_context, mock_policy,
+                                       mock_load, mock_template):
         for id_ in range(4):
             temp_uuid = uuidutils.generate_uuid()
             obj_utils.create_test_cluster(self.context, id=id_,
@@ -493,7 +494,9 @@ class TestPatch(api_base.FunctionalTest):
             '/clusters/%s/?rollback=True' % self.cluster_obj.uuid,
             [{'path': '/node_count', 'value': node_count,
               'op': 'replace'}],
-            headers={'OpenStack-API-Version': 'container-infra 1.3'})
+            headers={'OpenStack-API-Version': 'container-infra 1.3',
+                     "X-Roles": "member"
+                     })
 
         self.mock_cluster_update.assert_called_once_with(
             mock.ANY, node_count, self.cluster_obj.health_status,
@@ -506,7 +509,9 @@ class TestPatch(api_base.FunctionalTest):
             '/clusters/%s/?rollback=False' % self.cluster_obj.uuid,
             [{'path': '/node_count', 'value': node_count,
               'op': 'replace'}],
-            headers={'OpenStack-API-Version': 'container-infra 1.3'})
+            headers={'OpenStack-API-Version': 'container-infra 1.3',
+                     "X-Roles": "member"
+                     })
 
         self.mock_cluster_update.assert_called_once_with(
             mock.ANY, node_count, self.cluster_obj.health_status,
@@ -519,7 +524,9 @@ class TestPatch(api_base.FunctionalTest):
             '/clusters/%s' % self.cluster_obj.uuid,
             [{'path': '/node_count', 'value': node_count,
               'op': 'replace'}],
-            headers={'OpenStack-API-Version': 'container-infra 1.9'},
+            headers={'OpenStack-API-Version': 'container-infra 1.9',
+                     "X-Roles": "member"
+                     },
             expect_errors=True)
 
         self.assertEqual(400, response.status_code)
@@ -530,7 +537,9 @@ class TestPatch(api_base.FunctionalTest):
             '/clusters/%s' % self.cluster_obj.uuid,
             [{'path': '/node_count', 'value': node_count,
               'op': 'replace'}],
-            headers={'OpenStack-API-Version': 'container-infra 1.10'})
+            headers={'OpenStack-API-Version': 'container-infra 1.10',
+                     "X-Roles": "member"
+                     })
 
         self.mock_cluster_update.assert_called_once_with(
             mock.ANY, node_count, self.cluster_obj.health_status,
@@ -707,18 +716,24 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_with_zero_node_count_fail(self):
         bdict = apiutils.cluster_post_data()
         bdict['node_count'] = 0
-        response = self.post_json('/clusters', bdict, expect_errors=True,
-                                  headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"})
+        response = self.post_json(
+            '/clusters', bdict, expect_errors=True,
+            headers={
+                "Openstack-Api-Version": "container-infra 1.9",
+                "X-Roles": "member"
+            })
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(400, response.status_int)
 
     def test_create_cluster_with_zero_node_count(self):
         bdict = apiutils.cluster_post_data()
         bdict['node_count'] = 0
-        response = self.post_json('/clusters', bdict,
-                                  headers={"Openstack-Api-Version":
-                                           "container-infra 1.10"})
+        response = self.post_json(
+            '/clusters', bdict,
+            headers={
+                "Openstack-Api-Version": "container-infra 1.10",
+                "X-Roles": "member"
+            })
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(202, response.status_int)
 
