@@ -13,14 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import importlib
 import inspect
-import mock
+from unittest import mock
 
 from oslo_config import cfg
 from oslo_utils import importutils
 from osprofiler import initializer as profiler_init
 from osprofiler import opts as profiler_opts
-import six.moves as six
 
 from magnum.common import profiler
 from magnum import conf
@@ -45,7 +45,7 @@ class TestProfiler(base.TestCase):
         for clsname in classes:
             # give the metaclass and trace_cls() decorator a chance to patch
             # methods of the classes above
-            six.reload_module(
+            importlib.reload(
                 importutils.import_module(clsname.rsplit('.', 1)[0]))
             cls = importutils.import_class(clsname)
 
@@ -79,4 +79,4 @@ class TestProfiler(base.TestCase):
     @mock.patch.object(conf, 'CONF', new=cfg.ConfigOpts())
     def test_setup_profiler_without_osprofiler(self, mock_init):
         profiler.setup('foo', 'localhost')
-        self.assertFalse(mock_init.called)
+        self.assertEqual(False, mock_init.called)
